# git.py: Specialization of `describe' for Git.
# Copyright (C) 2013  Stephen Compall

# Julython-commit is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# Julython-commit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Julython-commit.  If not, see <http://www.gnu.org/licenses/>.

import re

from dulwich import repo as gitrepo
from julythoncommit.describe import Config

_origin_patterns = [(re.compile(reg), exps) for reg, exps in [
    (r'git://gitorious.org/([^/]+)/(.*).git',
     (ur'https://gitorious.org/\1/\2', ur'\2',
      r'https://gitorious.org/\1/\2/commit/%s'))
]]

def config(dirpath='.'):
    repoconf = gitrepo.Repo(dirpath).get_config_stack().get
    inferred_url, inferred_name, inferred_commitpat = _infer_origin(
        repoconf(('remote', 'origin'), 'url')) or (None, None, None)
    return Config(repoconf('julython', 'repo_url') or inferred_url,
                  repoconf('julython', 'repo_name') or inferred_name,
                  repoconf('gitweb', 'description'),
                  repoconf('julython', 'commit_pattern')
                  or inferred_commitpat)

def _infer_origin(origin_url):
    for reg, exps in _origin_patterns:
        if reg.match(origin_url):
            return tuple(reg.sub(exp, origin_url) for exp in exps)

# git.py ends here
